==> common-1.3.0.14-sources.jar: cn/gtmap/gtc/workflow/domain/manage/FlowableLogDto.java <==
package cn.gtmap.gtc.workflow.domain.manage;

/**
 * @author <a href="mailto:xuchao@gtmap.cn">xuchao</a>
 * @version 1.0.2019/3/21
 * @description  工作流操作日志对象
 */
public class FlowableLogDto {

    //流程实例id
    private String processInstanceId;
    //流程定义名称
    private String processDefinitionName;
    //当前活动id
    private String activityId;
    //当前活动名称
    private String activityName;
    //当前任务id
    private String taskId;


    public String getProcessInstanceId() {
        return processInstanceId;
    }

    public FlowableLogDto setProcessInstanceId(String processInstanceId) {
        this.processInstanceId = processInstanceId;
        return this;
    }

    public String getProcessDefinitionName() {
        return processDefinitionName;
    }

    public FlowableLogDto setProcessDefinitionName(String processDefinitionName) {
        this.processDefinitionName = processDefinitionName;
        return this;
    }

    public String getActivityId() {
        return activityId;
    }

    public FlowableLogDto setActivityId(String activityId) {
        this.activityId = activityId;
        return this;
    }

    public String getActivityName() {
        return activityName;
    }

    public FlowableLogDto setActivityName(String activityName) {
        this.activityName = activityName;
        return this;
    }

    public String getTaskId() {
        return taskId;
    }

    public FlowableLogDto setTaskId(String taskId) {
        this.taskId = taskId;
        return this;
    }

}

==> common-1.3.0.58-sources.jar: cn/gtmap/gtc/workflow/domain/manage/FlowableLogDto.java <==
package cn.gtmap.gtc.workflow.domain.manage;

import org.springframework.util.StringUtils;

/**
 * @author <a href="mailto:xuchao@gtmap.cn">xuchao</a>
 * @version 1.0.2019/3/21
 * @description  工作流操作日志对象
 */
public class FlowableLogDto {

    //流程实例id
    private String processInstanceId;
    //流程定义名称
    private String processDefinitionName;
    //当前活动id
    private String activityId;
    //当前活动名称
    private String activityName;
    //当前任务id
    private String taskId;

    private String reason;

    private String opinion;

    private String principalName;


    public String getProcessInstanceId() {
        return processInstanceId;
    }

    public FlowableLogDto setProcessInstanceId(String processInstanceId) {
        this.processInstanceId = processInstanceId;
        return this;
    }

    public String getProcessDefinitionName() {
        return processDefinitionName;
    }

    public FlowableLogDto setProcessDefinitionName(String processDefinitionName) {
        this.processDefinitionName = processDefinitionName;
        return this;
    }

    public String getActivityId() {
        return activityId;
    }

    public FlowableLogDto setActivityId(String activityId) {
        this.activityId = activityId;
        return this;
    }

    public String getActivityName() {
        return activityName;
    }

    public FlowableLogDto setActivityName(String activityName) {
        this.activityName = activityName;
        return this;
    }

    public String getTaskId() {
        return taskId;
    }

    public FlowableLogDto setTaskId(String taskId) {
        this.taskId = taskId;
        return this;
    }

    public String getReason() {
        return reason;
    }

    public FlowableLogDto setReason(String reason) {
        this.reason = reason;
        return this;
    }

    public String getPrincipalName() {
        return principalName;
    }

    public FlowableLogDto setPrincipalName(String principalName) {
        this.principalName = principalName;
        return this;
    }

    public String getOpinion() {
        return opinion;
    }

    public void setOpinion(String opinion) {
        if (StringUtils.isEmpty(opinion)){
            this.opinion = "无";
        }
        this.opinion = opinion;
    }
}
